==> calendar-v1.7.21.zip: calendar/messages/sv/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Lägg till</strong> Profilkalender',
    '<strong>Choose</strong> target calendar' => '<strong>Välj</strong> kalender',
    '<strong>Reminder</strong> settings' => '<strong>Påminnelse</strong> inställning',
    'Add all Space members with status {status}' => 'Lägg till alla forum-medlemmar med status {status}',
    'Add participants...' => 'Lägg till deltagare...',
    'Added: {users}' => 'Lade till: {users}',
    'Additional Information for participants' => 'Ytterligare information för deltagare',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Lägger till en kalender för privata eller publika aktiviteter till din profil och huvudmeny.',
    'Adds an event calendar to this space.' => 'Lägger till en kalender till detta forum',
    'After (occurrences)' => 'Efter',
    'All Day' => 'Hela dagen',
    'Allow option \'Decline\'' => 'Tillåt alternativet "Avvisa"',
    'Allow option \'Undecided\'' => 'Tillåt alternativet "Osäker"',
    'Allows the user to create new calendar entries' => 'Tillåter användaren att skapa nya kalenderinlägg',
    'Allows the user to edit/delete existing calendar entries' => 'Tillåter användaren att ändra/radera kalenderinlägg',
    'Attending' => 'Närvarar',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Innan en målkalender kan väljas måste modulen aktiveras i minst ett forum.',
    'Birthday' => 'Födelsedag',
    'Calendar' => 'Kalender',
    'Cancel Event' => 'Ställ in aktivitet',
    'Cannot remove the participant!' => 'Det går inte att ta bort deltagaren!',
    'Create entry' => 'Skapa inlägg',
    'Custom reminder' => 'Anpassad påminnelse',
    'Day' => 'Dag',
    'Days' => 'Dagar',
    'Default reminder settings' => 'Standardinställningar för påminnelser',
    'Delete all events' => 'Ta bort alla händelser',
    'Deleted' => 'Raderat',
    'Description' => 'Beskrivning',
    'Do you want to install this module on your profile?' => 'Vill du installera denna modul i din profil',
    'Download ICS' => 'Ladda ner ICS',
    'Edit' => 'Ändra',
    'Edit Event' => 'Redigera händelse',
    'Edit all events' => 'Ändra alla händelser',
    'Edit this and following events' => 'Redigera det här och följande händelser',
    'Edit this event' => 'Redigera den här händelsen',
    'Email' => 'E-post',
    'Enable' => 'Aktivera',
    'Enable Reminder' => 'Aktivera påminnelse',
    'End' => 'Slut',
    'End Date' => 'Slutdatum',
    'End Time' => 'Sluttid',
    'End time must be after start time!' => 'Slut tid måste vara efter starttid',
    'Event' => 'Aktivitet',
    'Event Type' => 'Aktivitetstyp',
    'Event Types' => 'Aktivitetstyper',
    'Event could not be deleted!' => 'Eventet kunde inte raderas!',
    'Event has been be deleted!' => 'Eventet har tagits bort!',
    'Event not found!' => 'Hittar inte event',
    'Export as {type}' => 'Exportera som {type}',
    'Files' => 'Filer',
    'Filter by types' => 'Filtrera efter typ',
    'Friday' => 'Fredag',
    'Here you can configure default settings for all calendar events.' => 'Här kan du ställa in standardinställningar för alla kalenderhändelser.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Här kan du ställa in globala standardpåminnelser. Dessa kan åtsidosättas av inställningar på forum-/profilnivå',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Här kan du ställa in standardpåminnelser för det här eventet. Användare har möjlighet att skriva över dessa inställningar genom länken <strong>Ställ in påminnelse</strong>',
    'Hour' => 'Timma',
    'I\'m attending' => 'Jag deltar',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'För att kunna lägga till kalenderuppgifter måste du aktivera kalendern först.',
    'Interested' => 'Intresserad',
    'Invalid date or time format!' => 'Felaktigt format',
    'Invalid day of month given' => 'Ogiltig dag i månaden angiven',
    'Invalid event type id selected.' => 'Felaktigt aktivitets-id valt.',
    'Invalid frequency given' => 'Ogiltig frekvens angiven',
    'Invalid interval given' => 'Ogiltigt intervall angivet',
    'Invalid week day selection' => 'Ogiltigt val av veckodag',
    'Invite' => 'Bjud in',
    'Invited: {users}' => 'Inbjudna: {users}',
    'List' => 'Lista',
    'Location' => 'Plats',
    'Manage entries' => 'Hantera inlägg',
    'Maximum number of participants' => 'Max antal deltagare',
    'Minute' => 'Minut',
    'Mode' => 'Läge',
    'Monday' => 'Måndag',
    'Month' => 'Månad',
    'Monthly on day {dayOfMonth}' => 'Månadsvis på dagen {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Månadsvis på den {position} {dayOfWeek}',
    'Months' => 'Månader',
    'Never' => 'Aldrig',
    'Next' => 'Nästa',
    'No new participants were added.' => 'Inga nya deltagare har lagts till.',
    'No new participants were invited.' => 'Inga nya deltagare bjöds in.',
    'No reminder' => 'Ingen påminnelse',
    'Notify participants about changes' => 'Meddela deltagare om ändringar',
    'On date' => 'På datum',
    'Participant removed.' => 'Deltagare borttagen.',
    'Participants' => 'Deltagare',
    'Participation Status' => 'Deltagarstatus',
    'Please select new participants.' => 'Välj nya deltagare.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Privata evenemang är endast synliga för dig och, om vänskapssystemet är aktiverat, för dina vänner.',
    'Profile Calendar' => 'Profilkalender',
    'Public' => 'Publik',
    'Recurring' => 'Återkommande',
    'Reopen Event' => 'Återöppna Aktivitet',
    'Repeat every' => 'Upprepa varje',
    'Saturday' => 'Lördag',
    'Set reminder' => 'Påminnelse',
    'Sorting' => 'Sortering',
    'Start Date' => 'Start datum',
    'Start Time' => 'Starttid',
    'Status cannot be updated.' => 'Status kan inte uppdateras.',
    'Status updated.' => 'Status uppdaterad.',
    'Sunday' => 'Söndag',
    'The event has already ended.' => 'Evenemanget har redan avslutats.',
    'This event does not support recurrent events' => 'Den här händelsen stödjer inte återkommande händelser',
    'Thursday' => 'Torsdag',
    'Time Zone' => 'Tidszon',
    'Title' => 'Rubrik',
    'Today' => 'I dag',
    'Tuesday' => 'Tisdag',
    'Upcoming {type}' => 'Kommande {type}',
    'Upcoming {type}: {title}' => 'Kommande {type}: {title}',
    'Use default reminder' => 'Använd standardpåminnelse',
    'User birthdays' => 'Användares födelsedagar',
    'Wednesday' => 'Onsdag',
    'Week' => 'Vecka',
    'Weeks' => 'Veckor',
    'Year' => 'År',
    'Years' => 'År',
    'You cannot invite participants!' => 'Du kan inte bjuda in deltagare!',
    'You don\'t have permission to delete this event!' => 'Du har inte tillåtelse att ta bort denna händelse!',
    'You have an <strong>{type}</strong> coming up' => 'Du har en/ett <strong>{type}</strong> händelse snart',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Du har en/ett <strong>{type}</strong> händelse snart: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Du har registrerats för evenemanget "{contentTitle}" i {spaceName}, med start kl. {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Du har registrerats för evenemanget "{contentTitle}", som börjar kl. {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Du har registrerats för evenemanget "{contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Din påminnelseinställning för händelse: <strong>\'{title}\'</strong>',
    'canceled' => 'Inställd',
    'disabled' => 'Inaktiverad',
    'first' => 'första',
    'forth' => 'fjärde',
    'global' => 'global',
    'last' => 'sista',
    'on weekdays' => 'på vardagar',
    'second' => 'andra',
    'third' => 'tredje',
    '{displayName} Birthday' => '{displayName} Födelsedag',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} lade precis till dig till aktiviteten "{contentTitle}" i forumet {spaceName} startar {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} lade just till dig till "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} bjöd precis in dig till eventet "{contentTitle}" i forumet {spaceName} som börjar kl. {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} har precis bjudit in dig till eventet "{contentTitle}".',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Display events within the next X days' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.5.zip: calendar/messages/sv/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Lägg till</strong> Profilkalender',
    '<strong>Choose</strong> target calendar' => '<strong>Välj</strong> kalender',
    '<strong>Reminder</strong> settings' => '<strong>Påminnelse</strong> inställning',
    'Add all Space members with status {status}' => 'Lägg till alla forum-medlemmar med status {status}',
    'Add participants...' => 'Lägg till deltagare...',
    'Added: {users}' => 'Lade till: {users}',
    'Additional Information for participants' => 'Ytterligare information för deltagare',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Lägger till en kalender för privata eller publika aktiviteter till din profil och huvudmeny.',
    'Adds an event calendar to this space.' => 'Lägger till en kalender till detta forum',
    'After (occurrences)' => 'Efter',
    'All Day' => 'Hela dagen',
    'Allow option \'Decline\'' => 'Tillåt alternativet "Avvisa"',
    'Allow option \'Undecided\'' => 'Tillåt alternativet "Osäker"',
    'Allows the user to create new calendar entries' => 'Tillåter användaren att skapa nya kalenderinlägg',
    'Allows the user to edit/delete existing calendar entries' => 'Tillåter användaren att ändra/radera kalenderinlägg',
    'Attending' => 'Närvarar',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Innan en målkalender kan väljas måste modulen aktiveras i minst ett forum.',
    'Birthday' => 'Födelsedag',
    'Calendar' => 'Kalender',
    'Cancel Event' => 'Ställ in aktivitet',
    'Cannot remove the participant!' => 'Det går inte att ta bort deltagaren!',
    'Create entry' => 'Skapa inlägg',
    'Custom reminder' => 'Anpassad påminnelse',
    'Day' => 'Dag',
    'Days' => 'Dagar',
    'Default reminder settings' => 'Standardinställningar för påminnelser',
    'Delete all events' => 'Ta bort alla händelser',
    'Deleted' => 'Raderat',
    'Description' => 'Beskrivning',
    'Do you want to install this module on your profile?' => 'Vill du installera denna modul i din profil',
    'Download ICS' => 'Ladda ner ICS',
    'Edit' => 'Ändra',
    'Edit Event' => 'Redigera händelse',
    'Edit all events' => 'Ändra alla händelser',
    'Edit this and following events' => 'Redigera det här och följande händelser',
    'Edit this event' => 'Redigera den här händelsen',
    'Email' => 'E-post',
    'Enable' => 'Aktivera',
    'Enable Reminder' => 'Aktivera påminnelse',
    'End' => 'Slut',
    'End Date' => 'Slutdatum',
    'End Time' => 'Sluttid',
    'End time must be after start time!' => 'Slut tid måste vara efter starttid',
    'Event' => 'Aktivitet',
    'Event Type' => 'Aktivitetstyp',
    'Event Types' => 'Aktivitetstyper',
    'Event could not be deleted!' => 'Eventet kunde inte raderas!',
    'Event has been be deleted!' => 'Eventet har tagits bort!',
    'Event not found!' => 'Hittar inte event',
    'Export as {type}' => 'Exportera som {type}',
    'Files' => 'Filer',
    'Filter by types' => 'Filtrera efter typ',
    'Friday' => 'Fredag',
    'Here you can configure default settings for all calendar events.' => 'Här kan du ställa in standardinställningar för alla kalenderhändelser.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Här kan du ställa in globala standardpåminnelser. Dessa kan åtsidosättas av inställningar på forum-/profilnivå',
    'Hour' => 'Timma',
    'I\'m attending' => 'Jag deltar',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'För att kunna lägga till kalenderuppgifter måste du aktivera kalendern först.',
    'Interested' => 'Intresserad',
    'Invalid date or time format!' => 'Felaktigt format',
    'Invalid day of month given' => 'Ogiltig dag i månaden angiven',
    'Invalid event type id selected.' => 'Felaktigt aktivitets-id valt.',
    'Invalid frequency given' => 'Ogiltig frekvens angiven',
    'Invalid interval given' => 'Ogiltigt intervall angivet',
    'Invalid week day selection' => 'Ogiltigt val av veckodag',
    'Invite' => 'Bjud in',
    'Invited: {users}' => 'Inbjudna: {users}',
    'List' => 'Lista',
    'Location' => 'Plats',
    'Manage entries' => 'Hantera inlägg',
    'Maximum number of participants' => 'Max antal deltagare',
    'Minute' => 'Minut',
    'Mode' => 'Läge',
    'Monday' => 'Måndag',
    'Month' => 'Månad',
    'Monthly on day {dayOfMonth}' => 'Månadsvis på dagen {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Månadsvis på den {position} {dayOfWeek}',
    'Months' => 'Månader',
    'Never' => 'Aldrig',
    'Next' => 'Nästa',
    'No new participants were added.' => 'Inga nya deltagare har lagts till.',
    'No new participants were invited.' => 'Inga nya deltagare bjöds in.',
    'No reminder' => 'Ingen påminnelse',
    'Notify participants about changes' => 'Meddela deltagare om ändringar',
    'On date' => 'På datum',
    'Participant removed.' => 'Deltagare borttagen.',
    'Participants' => 'Deltagare',
    'Participation Status' => 'Deltagarstatus',
    'Please select new participants.' => 'Välj nya deltagare.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Privata evenemang är endast synliga för dig och, om vänskapssystemet är aktiverat, för dina vänner.',
    'Profile Calendar' => 'Profilkalender',
    'Public' => 'Publik',
    'Recurring' => 'Återkommande',
    'Reopen Event' => 'Återöppna Aktivitet',
    'Repeat every' => 'Upprepa varje',
    'Saturday' => 'Lördag',
    'Set reminder' => 'Påminnelse',
    'Sorting' => 'Sortering',
    'Start Date' => 'Start datum',
    'Start Time' => 'Starttid',
    'Status cannot be updated.' => 'Status kan inte uppdateras.',
    'Status updated.' => 'Status uppdaterad.',
    'Sunday' => 'Söndag',
    'The event has already ended.' => 'Evenemanget har redan avslutats.',
    'This event does not support recurrent events' => 'Den här händelsen stödjer inte återkommande händelser',
    'Thursday' => 'Torsdag',
    'Time Zone' => 'Tidszon',
    'Title' => 'Rubrik',
    'Today' => 'I dag',
    'Tuesday' => 'Tisdag',
    'Upcoming {type}' => 'Kommande {type}',
    'Upcoming {type}: {title}' => 'Kommande {type}: {title}',
    'Use default reminder' => 'Använd standardpåminnelse',
    'User birthdays' => 'Användares födelsedagar',
    'Wednesday' => 'Onsdag',
    'Week' => 'Vecka',
    'Weeks' => 'Veckor',
    'Year' => 'År',
    'Years' => 'År',
    'You cannot invite participants!' => 'Du kan inte bjuda in deltagare!',
    'You don\'t have permission to delete this event!' => 'Du har inte tillåtelse att ta bort denna händelse!',
    'You have an <strong>{type}</strong> coming up' => 'Du har en/ett <strong>{type}</strong> händelse snart',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Du har en/ett <strong>{type}</strong> händelse snart: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Du har registrerats för evenemanget "{contentTitle}" i {spaceName}, med start kl. {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Du har registrerats för evenemanget "{contentTitle}", som börjar kl. {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Du har registrerats för evenemanget "{contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Din påminnelseinställning för händelse: <strong>\'{title}\'</strong>',
    'canceled' => 'Inställd',
    'disabled' => 'Inaktiverad',
    'first' => 'första',
    'forth' => 'fjärde',
    'global' => 'global',
    'last' => 'sista',
    'on weekdays' => 'på vardagar',
    'second' => 'andra',
    'third' => 'tredje',
    '{displayName} Birthday' => '{displayName} Födelsedag',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} lade precis till dig till aktiviteten "{contentTitle}" i forumet {spaceName} startar {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} lade just till dig till "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} bjöd precis in dig till eventet "{contentTitle}" i forumet {spaceName} som börjar kl. {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} har precis bjudit in dig till eventet "{contentTitle}".',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Display events within the next X days' => '',
    'Filter' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];
